# PyQt6Ads

[![License](https://img.shields.io/pypi/l/PyQt6Ads.svg?color=green)](https://github.com/pyapp-kit/PyQt6Ads/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/PyQt6Ads.svg?color=green)](https://pypi.org/project/PyQt6Ads)
[![Python Version](https://img.shields.io/pypi/pyversions/PyQt6Ads.svg?color=green)](https://python.org)
[![Build](https://github.com/pyapp-kit/PyQt6Ads/actions/workflows/pypi.yml/badge.svg)](https://github.com/pyapp-kit/PyQt6Ads/actions/workflows/pypi.yml)

PyQt6 Bindings for (the amazing)
[Qt-Advanced-Docking-System](https://github.com/githubuser0xFFFF/Qt-Advanced-Docking-System)

[![Video Advanced
Docking](https://github.com/githubuser0xFFFF/Qt-Advanced-Docking-System/blob/483bb7354ace8f07b76f483ec167e84467ac3977/doc/advanced-docking_video.png)](https://www.youtube.com/watch?v=7pdNfafg3Qc)

## Installation

```sh
pip install PyQt6Ads
```

## Usage

Please see [documentation in the upstream
repo](https://github.com/githubuser0xFFFF/Qt-Advanced-Docking-System/blob/master/doc/user-guide.md).

See also [examples in this repo](./examples/).

The autogenerated type stubs are also useful for understanding the API.

## Alternatives

- **For PySide6**: See <https://github.com/mborgerson/pyside6_qtads>
- **For PyQt5**: See <https://github.com/githubuser0xFFFF/Qt-Advanced-Docking-System#pyqt5> (in the upstream repo)
